@@ -18,6 +18,7 @@
                                  absoluteSize = 0.5,
                                  zoneNames = NULL,
                                  drawLegend = TRUE,
+                                 na.action = "na.omit",
                                  ...) {
     ## inline function for custom axis
     axis.VarLabs <- function(side, ...) {
@@ -43,6 +44,7 @@
     ## ylabel
     if(is.null(ylab))
         ylab <- deparse(substitute(y))
+
     ## do we need to sort variables
     if(missing(sort))
         sort <- "none"
@@ -63,9 +65,13 @@
     }
     if(rev.sort)
         ord <- rev(ord)
+    ## apply ordering
     x <- x[, ord]
+
+    ## stack the data
     sx <- stack(x)
-    sx$ind <- factor(sx$ind, levels = colnames(x))
+    sx$ind <- factor(sx$ind, levels = colnames(x)) # add grouping variable
+
     ## check length of y
     if(!isTRUE(all.equal((leny <- length(y)), (nr <- nrow(sx))))) {
         ## if length(y) == nrow(sx)/n.vars, then expand
@@ -74,19 +80,29 @@
         else
             stop("Ambiguous 'length(y)';\nmust be equal to 'nrow(x)' or\n'nrow(x) / number of species'.")
     }
+
+    ## handle NA's, by default NA pass in here fine, but this messes
+    ## up line plots or polygons for example
+    NAFUN <- match.fun(na.action)
+    sx <- NAFUN(sx)
+    ## and apply to `y` too
+    if(!is.null(NAS <- na.action(sx))) {
+        y <- y[-NAS]
+    }
+
     ## plot parameters
-    maxy <- max(y)
-    miny <- min(y)
-    ## add padYlim * range as per base graphics
-    padY <- 0.01
+    maxy <- max(y, na.rm = TRUE)
+    miny <- min(y, na.rm = TRUE)
+    ## add padYlim * range as per base graphics - 4% of range
+    padY <- 0.04
     if(missing(ylim)) {
         ##diffy <- padY * (maxy - miny)
         diffy <- maxy - miny
         ylim <- c(miny - (padY * diffy), maxy + (padY * diffy))
     } else {
         ## should these be ylim[1] and ylim[2] ???
-        minLim <- min(ylim)
-        maxLim <- max(ylim)
+        minLim <- min(ylim, na.rm = TRUE)
+        maxLim <- max(ylim, na.rm = TRUE)
         ## add padY * range as per base graphics
         diffy <- abs(diff(c(minLim, maxLim)))
         ylim <- if(minLim > maxLim)
@@ -110,13 +126,14 @@
         stop("Ambiguous entry in 'varTypes'.\nMust be one of \"relative\", or \"absolute\"")
     ## compute max abundances per relative column, which is used
     ## to scale the panel widths layout.widths parameter)
-    max.abun <- sapply(x, function(x) round(max(x), 1), USE.NAMES = FALSE)
+    max.abun <- sapply(x, function(x) round(max(x, na.rm = TRUE), 1),
+                       USE.NAMES = FALSE)
     ## absolute panels should be set to absoluteSize of max.abun
     panelWidths <- max.abun
     ABS <- which(varTypes == "absolute")
     REL <- which(varTypes == "relative")
     if(any(REL)) {
-        panelWidths[ABS] <- absoluteSize * max(max.abun[REL])
+        panelWidths[ABS] <- absoluteSize * max(max.abun[REL], na.rm = TRUE)
     } else {
         panelWidths[ABS] <- absoluteSize
     }
@@ -124,8 +141,8 @@
     xlimits <- lapply(max.abun * 1.05, function(x) c(0, x))
     if(any(ABS)) {
         ## but need any "absolute" panels setting to +/- 0.05(range)
-        min.vars <- sapply(x[ABS], min, USE.NAMES = FALSE)
-        max.vars <- sapply(x[ABS], max, USE.NAMES = FALSE)
+        min.vars <- sapply(x[ABS], min, na.rm = TRUE, USE.NAMES = FALSE)
+        max.vars <- sapply(x[ABS], max, na.rm = TRUE, USE.NAMES = FALSE)
         ranges <- (0.04 * (max.vars - min.vars))
         xlimits[ABS] <- as.list(data.frame(t(cbind(min.vars - ranges,
                                                    max.vars + ranges))))
@@ -133,7 +150,8 @@
     ## scales in xyplot call
     scales <- list(cex = 0.75, tck = 0.75,
                    y = list(axs = "r", limits = ylim),
-                   x = list(axs = "r", rot = 45, relation = "free", limits = xlimits))
+                   x = list(axs = "r", rot = 45, relation = "free",
+                   limits = xlimits))
     par.strip.text <- list(cex = 0.75)
     str.max <- 1
     if(!isTRUE(strip)) {
@@ -142,7 +160,9 @@
             convertWidth(grobWidth(textGrob(x, gp = gp)), "lines",
                          valueOnly = TRUE)
         }
-        str.max <- max(sapply(levels(sx$ind), convWidth, gp, USE.NAMES = FALSE))
+        str.max <- max(sapply(levels(sx$ind), convWidth, gp,
+                              USE.NAMES = FALSE),
+                       na.rm = TRUE)
         str.max <- ceiling(str.max) + topPad
     }
     ## Legend specification for Zones
