@@ -20,29 +20,29 @@ summary.predict.mat <- function(object, ...)
 print.summary.predict.mat <- function(x,
                                       digits = max(3, getOption("digits") - 3),
                                       ...)
-  {
+{
     print.predict.mat(x)
     if(!is.null(x$bootstrap)) {
-      k.model <- x$model$k
-      k.boot <- x$bootstrap$k
-      dat <- data.frame(Obs = x$observed,
-                        Est = x$model$estimated[k.model, ],
-                        Resid = x$model$residuals[k.model, ],
-                        Boot.Est = x$bootstrap$estimated[, k.boot],
-                        Boot.Resid = x$bootstrap$residuals[, k.boot],
-                        s1 = x$sample.errors$s1[, k.boot],
-                        s2 = x$sample.errors$s2[, k.boot],
-                        RMSEP = x$sample.errors$rmsep[, k.boot])
-      cat("\nTraining set assessment:\n\n")
-      print(dat, digits = digits)
+        k.model <- x$model$k
+        k.boot <- x$bootstrap$k
+        dat <- data.frame(Obs = x$observed,
+                          Est = x$model$estimated[k.model, ],
+                          Resid = x$model$residuals[k.model, ],
+                          Boot.Est = x$bootstrap$estimated[, k.boot],
+                          Boot.Resid = x$bootstrap$residuals[, k.boot],
+                          s1 = x$sample.errors$s1[, k.boot],
+                          s2 = x$sample.errors$s2[, k.boot],
+                          RMSEP = x$sample.errors$rmsep[, k.boot])
+        cat("\nTraining set assessment:\n\n")
+        print(dat, digits = digits)
     } else {
-      k.model <- x$model$k
-      dat <- data.frame(Obs = x$observed,
-                        Est = as.numeric(x$model$estimated[k.model]),
-                        Resid = x$model$residuals$residuals)
-      rownames(dat) <- names(x$model$estimated)
+        k.model <- x$model$k
+        dat <- data.frame(Obs = x$observed,
+                          Est = as.numeric(x$model$estimated),
+                          Resid = x$model$residuals$residuals)
+        rownames(dat) <- names(x$model$estimated)
     }
     cat("\nTraining set assessment:\n\n")
     print(dat, digits = digits)
     invisible(x)
-  }
+}
